insert_blob

Function insert_blob 

pub fn insert_blob(
    conn: &Connection,
    table_name: &str,
    columns: &[Column],
    source: impl Read,
) -> Result<()>
Inserts binary data from standard input into the table.

This reads source in chunks, stores them in a temporary table, and then aggregates them into the target BLOB column using SQLite’s group_concat.