prepare_db

Function prepare_db 

pub fn prepare_db(
    conn: &Connection,
    table_name: &str,
    reset: bool,
    columns: &[Column],
) -> Result<()>
Prepares the database schema by creating tables and synchronizing columns.

If reset is true, the existing table is dropped and recreated.