SanitizedIdentifier

Struct SanitizedIdentifier 

pub struct SanitizedIdentifier(/* private fields */);
A wrapper for strings that have been formatted as safe SQL identifiers (e.g., “column_name”).

Implementations

Source

impl SanitizedIdentifier

pub fn new(s: impl AsRef<str>) -> SanitizedIdentifier

Wraps a string in double quotes and escapes internal quotes.

pub fn as_str(&self) -> &str

Returns the internal sanitized string.