Module txmgmt

Module txmgmt 

module for managing a transaction daemon

Enums

ColumnData
Column data
Error
Message
A IPC message to communicate between daemon and client
ShareableBuffer
A helper enum for serializing/deserializing byte buffers that can be shared or owned

Functions

client_commit
Entrypoint for committing transactions.
client_disconnect
Entrypoint for disconnecting.
client_main
Main entrypoint for clients sending data.
client_revert
Entrypoint for reverting transactions.
receive_msg
Read a message from the given source.
send_msg
Send a mesage into the given sink.
tx_daemon_main
Main entry point for a daemon. Opens the connection and connects to the socket.
tx_main
Main entry point for tx management. Expects the connection and socket to be already opened.