module for managing a transaction daemon
Enums
- Column
Data - Column data
- Error
- Message
- A IPC message to communicate between daemon and client
- Shareable
Buffer - A helper enum for serializing/deserializing byte buffers that can be shared or owned
Functions
- client_
commit - Entrypoint for committing transactions.
- client_
disconnect - Entrypoint for disconnecting.
- client_
main - Main entrypoint for clients sending data.
- client_
revert - Entrypoint for reverting transactions.
- receive_
msg - Read a message from the given source.
- send_
msg - Send a mesage into the given sink.
- tx_
daemon_ main - Main entry point for a daemon. Opens the connection and connects to the socket.
- tx_main
- Main entry point for tx management. Expects the connection and socket to be already opened.